"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../../utils");
const colors_1 = require("@ant-design/colors");
const color_1 = require("../../constants/color");
const context_1 = require("../../context");
const color_func_1 = require("../../color-func");
const __1 = require("..");
const color_2 = require("../../constants/color");
const COLOR_NAME_RE = /(\w+)-(\d)+$/;
const COLOR_MAIN_RE = /(\w+)-6$/;
const BASE_NAME_RE = /(\w+)-(base)$/;
const defaultMainColorMap = new Map();
const baseColorMap = new Map();
const rule = (0, utils_1.defineRuleOptions)({
    styleFilePath: 'style/color/colors.less',
    atRules: [
        (atRule) => {
            if (BASE_NAME_RE.test(atRule.name)) {
                baseColorMap.set(atRule.name, atRule.value);
            }
            // 修改color.less为css变量，并记录到数组内
            if (COLOR_MAIN_RE.test(atRule.name)) {
                let value = atRule.value;
                const match = atRule.name.match(COLOR_MAIN_RE);
                const colorName = match?.[1];
                if (value?.startsWith('@') && BASE_NAME_RE.test(value)) {
                    value = baseColorMap.get(value.replace(/^@/, ''));
                }
                if (colorName && value) {
                    const colors = (0, colors_1.generate)(value);
                    const mainColor = colors[5];
                    defaultMainColorMap.set(colorName, mainColor);
                    colors.forEach((color, index) => {
                        context_1.antDesignColorMap.set(`${colorName}-${index + 1}`, color);
                    });
                    // 对一些特殊的环境变量进行写入，如 primary-color error-color
                    const addColors = color_1.ANT_DESIGN_COLOR_MAP.get(atRule.name);
                    if (addColors && Array.isArray(addColors)) {
                        addColors.forEach((item) => {
                            const mainKey = `${colorName}-6`;
                            context_1.antDesignColorMap.set(item, `var(--${mainKey})`);
                        });
                    }
                    // 额外添加ant-design系列的 primary-{n}
                    if (colorName === color_1.ANT_DESIGN_BASE_COLOR) {
                        colors.forEach((color, index) => {
                            // primary-color
                            context_1.antDesignColorMap.set(`primary-${index + 1}`, index === 5 ? 'var(--primary-color)' : color);
                        });
                    }
                }
                atRule.value = `var(--${atRule.name})`;
            }
            if (COLOR_NAME_RE.test(atRule.name) &&
                atRule.name.startsWith(color_2.PRIMARY_KEY)) {
                atRule.value = `var(--${atRule.name})`;
            }
        },
    ],
    formatResult: (result) => {
        let cssText = ``;
        for (const [key, value] of defaultMainColorMap) {
            cssText += `\t--${key}-6: ${value};\n`;
        }
        result.css = `:root{\n${cssText}}\n` + result.css;
        return result;
    },
});
const processColorFunc = (0, color_func_1.createProcessColorFunc)();
for (const processFunc of processColorFunc) {
    (0, __1.mergeRule)(rule, processFunc);
}
exports.default = rule;
